@@ -3,13 +3,14 @@ from PyQt5.QtCore import QLocale
 from oyaml import MappingNode
 from pint import UnitRegistry
 from pint.quantity import build_quantity_class
-
+import logging
 QLocale.setDefault(QLocale("US"))
 
 
 # TODO: Make save positions group resizable
 # TODO: Offer tooltip for saved comment so long comment can be seen
 # TODO: Add process ID for session device
+# TODO: Somehow make sure, that not two instances of session are running
 
 class GuiTypeError(Exception):
     pass
@@ -90,4 +91,5 @@ def pint_dumper(dumper, data):
 yaml.add_representer(units.Quantity, pint_dumper)
 yaml.add_constructor(u'!Pint', pint_constructor)
 
-# TODO: Somehow make sure, that not two instances of session are running
+logging.MACRO_STATE = 51
+logging.addLevelName(logging.MACRO_STATE, "MACRO_STATE")
\ No newline at end of file
