@@ -2,7 +2,7 @@ import socket
 import time
 from _socket import timeout
 from threading import Thread
-
+import re
 import numpy as np
 import serial
 
@@ -53,9 +53,9 @@ class DeviceGalil(DeviceSocket):
         self["Digital output"] = {}
 
         for i in range(8):
-            self.create_attribute(self.AI_config[i], "Analog input", min_value=0., max_value=10., unit=u"V",
+            self.create_attribute(self.AI_config[i], "Analog input", unit=u"V",
                                   default_type=np.float16, decimals=4, readonly=True)
-            self.create_attribute(self.AO_config[i], "Analog output", min_value=0., max_value=10., unit=u"V",
+            self.create_attribute(self.AO_config[i], "Analog output", unit=u"V",
                                   set_function=lambda value, output=i: self.set_analog_output(output, value),
                                   default_type=np.float16, decimals=4)
             self.create_attribute(self.DI_config[i], "Digital input", default_type=np.bool, readonly=True)
@@ -107,8 +107,9 @@ class DeviceGalil(DeviceSocket):
 
         self.command("\x12\x16;")  # Get galil model and firmware version
         # self.command("TZ;") # Get all inputs and outputs
-        self.command(self.analog_output_limits_command)
-        self.command(self.analog_input_limits_command)
+        # self.command(self.analog_output_limits_command)
+        # self.command(self.analog_input_limits_command)
+        self.command("ID;") # Get input / output configuration
         self.command(self.analog_input_readout_command)
         self.command(self.analog_output_readout_command)
         self.command(self.digital_lO_readout_command, callback=_finish_configuration)
@@ -198,6 +199,32 @@ class DeviceGalil(DeviceSocket):
                 self.set_raw_value(("Digital input", self.DI_config[8 + bit]), bool(di1 & (1 << bit)))
                 self.set_raw_value(("Digital output", self.DO_config[bit]), bool(do0 & (1 << bit)))
                 self.set_raw_value(("Digital output", self.DO_config[8 + bit]), bool(do1 & (1 << bit)))
+        elif command == "ID;":
+            for line in output.split("\r\n"):
+                if line.startswith("analog inputs"):
+                    if "programmable range" in line:
+                        self.command(self.analog_input_limits_command)
+                    else:
+                        values = re.search("analog inputs ([0-9]+)\-([0-9]+) = [0-9]+ bits range ([0-9]+) to ([0-9]+)", line)
+                        if values is not None:
+                            first_input, last_input, min_value, max_value = values.group(1), values.group(2), values.group(3), values.group(4)
+                            for index in range(int(first_input), int(last_input) + 1):
+                                if self.get_attribute(("Analog input", self.AI_config[index], MIN)) in (None, np.inf, -np.inf):
+                                    self.set_raw_value(("Analog input", self.AI_config[index]), float(min_value), key=MIN)
+                                if self.get_attribute(("Analog input", self.AI_config[index], MAX)) in (None, np.inf, -np.inf):
+                                    self.set_raw_value(("Analog input", self.AI_config[index]), float(max_value), key=MAX)
+                if line.startswith("analog outputs"):
+                    if "programmable range" in line:
+                        self.command(self.analog_output_limits_command)
+                    else:
+                        values = re.search("analog outputs ([0-9]+)\-([0-9]+) = [0-9]+ bits range ([0-9]+) to ([0-9]+)", line)
+                        if values is not None:
+                            first_input, last_input, min_value, max_value = values.group(1), values.group(2), values.group(3), values.group(4)
+                            for index in range(int(first_input), int(last_input) + 1):
+                                if self.get_attribute(("Analog output", self.AO_config[index], MIN)) in (None, np.inf, -np.inf):
+                                    self.set_raw_value(("Analog output", self.AO_config[index]), float(min_value), key=MIN)
+                                if self.get_attribute(("Analog output", self.AO_config[index], MAX)) in (None, np.inf, -np.inf):
+                                    self.set_raw_value(("Analog output", self.AO_config[index]), float(max_value), key=MAX)
         elif command == "\x12\x16;":
             self.set_raw_value(ATTR_MODEL, output)
         elif command == self.analog_output_limits_command:
@@ -213,8 +240,10 @@ class DeviceGalil(DeviceSocket):
                 # Append tuple representing analog output data type
                 new_date_type.append((self.AO_config[index], dt))
                 # Set both limits for analog channel
-                self.set_attribute(("Analog output", self.AO_config[index], MIN), lower_limit)
-                self.set_attribute(("Analog output", self.AO_config[index], MAX), upper_limit)
+                if self.get_attribute(("Analog output", self.AO_config[index], MIN)) in (None, np.inf, -np.inf):
+                    self.set_raw_value(("Analog output", self.AO_config[index]), lower_limit, key=MIN)
+                if self.get_attribute(("Analog output", self.AO_config[index], MAX)) in (None, np.inf, -np.inf):
+                    self.set_raw_value(("Analog output", self.AO_config[index]), upper_limit, key=MAX)
             # Set numpy data type, which is used to parse binary UDP readout
             self.analog_output_date_type = np.dtype(new_date_type)
         elif command == self.analog_input_limits_command:
@@ -230,8 +259,10 @@ class DeviceGalil(DeviceSocket):
                 # Append tuple representing analog output data type
                 new_date_type.append((self.AO_config[index], dt))
                 # Set both limits for analog channel
-                self.set_attribute(("Analog input", self.AI_config[index], MIN), lower_limit)
-                self.set_attribute(("Analog input", self.AI_config[index], MAX), upper_limit)
+                if self.get_attribute(("Analog input", self.AI_config[index], MIN)) in (None, np.inf, -np.inf):
+                    self.set_raw_value(("Analog input", self.AI_config[index]), lower_limit, key=MIN)
+                if self.get_attribute(("Analog input", self.AI_config[index], MAX)) in (None, np.inf, -np.inf):
+                    self.set_raw_value(("Analog input", self.AI_config[index]), upper_limit, key=MAX)
             # Set numpy data type, which is used to parse binary UDP readout
             self.analog_input_date_type = np.dtype(new_date_type)
 
