@@ -92,7 +92,7 @@ class DeviceKaraboBridge(Device):
 
         self.update_metadata(list(metadata.values())[0])
 
-    def _set(self, attribute, value):
+    def _set(self, attribute, value, callback=None):
         """
         This sets Device attribute.
         Use this function when You want to set attribute by tuple or list key.
