@@ -35,7 +35,7 @@ class DeviceRheodyneBox(DeviceNiCard):
                                       set_function=lambda sn, i=i + 1, j=j + 1: self.set_sample_name(i, j, sn))
 
             self.create_attribute(ATTR_CURRENT_SAMPLE, switch_name, default_type=sample_names,
-                                  set_function=lambda sn, i=i + 1: self.set_current_sample(i, sn)
+                                  set_function=lambda sn, i=i + 1: self.set_current_sample(i, sn))
             self.create_attribute(ATTR_CURRENT_CHANNEL, switch_name, default_type=np.uint16, min_value=1,
                                   max_value=self.max_channels_per_switch,
                                   set_function=lambda ch, i=i + 1: self.set_current_channel(i, ch))
