@@ -4,8 +4,9 @@ import shutil
 import time
 from collections import OrderedDict
 from threading import RLock
-import oyaml as yaml
+
 import numpy as np
+import oyaml as yaml
 import psutil
 
 import kamzik3
@@ -65,6 +66,13 @@ class DeviceSession(Device):
         self.create_attribute(ATTR_ALLOW_DEVICE_LOG, default_value=True, default_type=np.bool)
         self.create_attribute(ATTR_ALLOW_ATTRIBUTE_LOG, default_value=True, default_type=np.bool)
         self.create_attribute(ATTR_ALLOW_MACRO_LOG, default_value=True, default_type=np.bool)
+        self.create_attribute(ATTR_ALLOW_RC, group=GROUP_RC, default_value=False, readonly=True, default_type=np.bool)
+        self.create_attribute(ATTR_MAIN_ROOM, group=GROUP_RC, default_value=self.device_id.lower(), readonly=True)
+        self.create_attribute(ATTR_AUTH_TOKEN, group=GROUP_RC, default_value=None, readonly=True, display=False)
+        self.create_attribute(ATTR_USER_NAME, group=GROUP_RC, default_value=None, readonly=True, display=False)
+        self.create_attribute(ATTR_PASSWORD, group=GROUP_RC, default_value=None, readonly=True, display=False)
+        self.create_attribute(ATTR_RC_MACRO_DISCUSSION, group=GROUP_RC, default_value=None, readonly=True)
+        self.create_attribute(ATTR_HOST, group=GROUP_RC, default_value="https://cfel-rocketchat.desy.de", readonly=True)
         self.create_attribute(ATTR_LOOPS_RUNNING, default_value=False, default_type=np.bool, readonly=True)
         self.create_attribute(ATTR_PROCESS_ID, default_value=os.getpid(), readonly=True)
         self.create_attribute(ATTR_CPU_USAGE, default_value=0, default_type=np.float, readonly=True, unit="%",
@@ -249,7 +257,9 @@ class DeviceSession(Device):
         logger = logging.getLogger(u"Console")
         set_rotating_file_handler(logger, os.path.join(log_directory, self.LOG_CONSOLE_OUTPUT_FILE))
         set_sys_exception_handler(logger)
-        # set_rocket_chat_handler(logger, level=logging.ERROR)
+        # if self.get_value(ATTR_ALLOW_RC):
+        #     discussion = "{}-{}".format(self.device_id.lower(), "error-log")
+        #     set_rocket_chat_handler(logger, level=logging.ERROR, main_room=self.device_id.lower(), discussion=discussion)
         logger.setLevel(self.log_level)
         logger.addHandler(handler)
 
@@ -266,7 +276,9 @@ class DeviceSession(Device):
 
         handler = get_console_handler()
         logger = logging.getLogger(u"Gui")
-        # set_rocket_chat_handler(logger, level=logging.ERROR)
+        # if self.get_value(ATTR_ALLOW_RC):
+        #     discussion = "{}-{}".format(self.device_id.lower(), "error-log")
+        #     set_rocket_chat_handler(logger, level=logging.ERROR, main_room=self.device_id.lower(), discussion=discussion)
         set_rotating_file_handler(logger, os.path.join(log_directory, self.LOG_GUI_OUTPUT_FILE))
         logger.setLevel(logging.DEBUG)
         logger.addHandler(handler)
@@ -302,7 +314,9 @@ class DeviceSession(Device):
         handler = get_console_handler()
         logger = logging.getLogger(u"Device")
         set_rotating_file_handler(logger, os.path.join(log_directory, self.LOG_DEVICE_OUTPUT_FILE))
-        # set_rocket_chat_handler(logger, level=logging.ERROR)
+        # if self.get_value(ATTR_ALLOW_RC):
+        #     discussion = "{}-{}".format(self.device_id.lower(), "error-log")
+        #     set_rocket_chat_handler(logger, level=logging.ERROR, channel=channel)
         logger.setLevel(self.log_level)
         logger.addHandler(handler)
 
@@ -320,10 +334,23 @@ class DeviceSession(Device):
         handler = get_console_handler()
         logger = logging.getLogger(u"Macro")
         set_rotating_file_handler(logger, os.path.join(log_directory, self.LOG_MACRO_OUTPUT_FILE))
-        # set_rocket_chat_handler(logger, level=logging.MACRO_STATE)
+        if self.get_value([GROUP_RC, ATTR_ALLOW_RC]):
+            discussion_name = self.get_value([GROUP_RC, ATTR_RC_MACRO_DISCUSSION])
+            if discussion_name is None:
+                discussion_name = "{}-{}".format(self.device_id.lower(), "macro-log")
+                self.set_value([GROUP_RC, ATTR_RC_MACRO_DISCUSSION], discussion_name)
+            user_credentials, auth_token = self._get_rc_auth()
+            set_rocket_chat_handler(logger, level=logging.MACRO_STATE, user_credentials=user_credentials,
+                                    auth_token=auth_token, main_room=self.device_id.lower(), discussion=discussion_name)
         logger.setLevel(logging.DEBUG)
         logger.addHandler(handler)
 
+    def _get_rc_auth(self):
+        rc_user = self.get_value([GROUP_RC, ATTR_USER_NAME])
+        rc_pass = self.get_value([GROUP_RC, ATTR_PASSWORD])
+        rc_auth_token = self.get_value([GROUP_RC, ATTR_AUTH_TOKEN])
+        return (rc_user, rc_pass), rc_auth_token
+
     def start_control_loops(self):
         if not self.get_value(ATTR_LOOPS_RUNNING):
             self.start_asyncore_loop()
