@@ -15,6 +15,8 @@ from kamzik3.devices.deviceSocket import DeviceSocket
 from kamzik3.snippets.snippetsDecorators import expose_method
 from kamzik3.snippets.snippetsUnits import device_units
 
+from kamzik3.constants import PREVIOUS
+
 """ Example of yaml configuration
 Smaract0: &Smaract0 !Device:kamzik3.devices.deviceSmaractMcs1.DeviceSmaractMcs1
     device_id: Smaract0
@@ -469,10 +471,10 @@ class DeviceSmaractMcs1Channel(DeviceChannel):
 
     def set_sensor_type(self, value, callback=None):
         self.logger.info(u"Set sensor type to {}".format(value))
-        if value != self.get_value(ATTR_SENSOR_TYPE):
+        if value != self.get_attribute([ATTR_SENSOR_TYPE, PREVIOUS]):
             self.remove_poll_command(":GP{}\n".format(self.channel), 250)
             self.remove_poll_command(":GA{}\n".format(self.channel), 250)
-
+            print(u":SST{},{}\n".format(self.channel, int(value)))
             token = self.command(u":SST{},{}\n".format(self.channel, int(value)), callback, with_token=True)
             self.get_sensor_type()
             return token
