@@ -155,7 +155,7 @@ class DeviceSmarpodEcm(DeviceSocket):
                                                                                  self.error_descriptions.get(error_code,
                                                                                                              "Unknown error"))
                 self.handle_command_error(command, readout_buffer)
-                command = RESPONSE_ERROR.decode()
+                command = RESPONSE_ERROR
         elif command == u"mst?\r\n":
             if int(output) <= 1:
                 # Motor is stopped or holding
@@ -209,9 +209,9 @@ class DeviceSmarpodEcm(DeviceSocket):
 
     def start_polling(self):
         super().start_polling()
-        self.poll_command("mst?\r\n", 200)
+        self.poll_command("mst?\r\n", 300)
         if self.get_value(ATTR_REFERENCED):
-            self.poll_command("pos?\r\n", 200)
+            self.poll_command("pos?\r\n", 300)
 
     def set_sensor_mode(self, mode, callback=None):
         self.logger.info(u"Set sensor mode to {}".format(mode))
