@@ -30,3 +30,12 @@ class DeviceDummy(Device):
 
     def command(self, command, callback=None, with_token=False, returning=True):
         raise DeviceError("Dummy device does not accept any commands.")
+
+    def handshake(self):
+        return True
+
+    def start_polling(self):
+        return
+
+    def close(self):
+        Device.close(self)
\ No newline at end of file
