@@ -242,6 +242,8 @@ class DeviceDebugWidget(Ui_Form, DeviceWidget):
         is_picture_in = False
         for key, value in attributes.items():
             if Attribute.is_attribute(value):
+                if value.get(DISPLAY) == False:
+                    continue
                 if column % columns == 0:
                     row += 1
                     column = 0
